@@ -1,8 +1,7 @@
 from abc import ABC
 import warnings
 
-from .util import enclose_in_parens
-from .syntax import build_obj_dict, create_dictionary_string
+from .syntax import PDFString, build_obj_dict, create_dictionary_string
 
 
 class Action(ABC):
@@ -13,15 +12,15 @@ class Action(ABC):
         """
         self.next = next_action
 
-    def serialize(self):
+    def serialize(self, _security_handler=None, _obj_id=None):
         raise NotImplementedError
 
-    def _serialize(self, key_values=None):
+    def _serialize(self, key_values=None, _security_handler=None, _obj_id=None):
         if key_values is None:
             key_values = {}
         if self.next:
             key_values["Next"] = self.next
-        obj_dict = build_obj_dict(key_values)
+        obj_dict = build_obj_dict(key_values, _security_handler, _obj_id)
         return create_dictionary_string(obj_dict, field_join=" ")
 
 
@@ -30,8 +29,12 @@ class URIAction(Action):
         super().__init__(next)
         self.uri = uri
 
-    def serialize(self):
-        return super()._serialize({"s": "/URI", "u_r_i": enclose_in_parens(self.uri)})
+    def serialize(self, _security_handler=None, _obj_id=None):
+        return super()._serialize(
+            {"s": "/URI", "u_r_i": PDFString(self.uri, encrypt=True)},
+            _security_handler=_security_handler,
+            _obj_id=_obj_id,
+        )
 
 
 class NamedAction(Action):
@@ -41,8 +44,12 @@ class NamedAction(Action):
             warnings.warn("Non-standard named action added")
         self.action_name = action_name
 
-    def serialize(self):
-        return super()._serialize({"s": "/Named", "n": f"/{self.action_name}"})
+    def serialize(self, _security_handler=None, _obj_id=None):
+        return super()._serialize(
+            {"s": "/Named", "n": f"/{self.action_name}"},
+            _security_handler=_security_handler,
+            _obj_id=_obj_id,
+        )
 
 
 class GoToAction(Action):
@@ -52,8 +59,12 @@ class GoToAction(Action):
         super().__init__(next_action)
         self.dest = dest
 
-    def serialize(self):
-        return super()._serialize({"s": "/GoTo", "d": self.dest})
+    def serialize(self, _security_handler=None, _obj_id=None):
+        return super()._serialize(
+            {"s": "/GoTo", "d": self.dest},
+            _security_handler=_security_handler,
+            _obj_id=_obj_id,
+        )
 
 
 class GoToRemoteAction(Action):
@@ -62,9 +73,11 @@ class GoToRemoteAction(Action):
         self.file = file
         self.dest = dest
 
-    def serialize(self):
+    def serialize(self, _security_handler=None, _obj_id=None):
         return super()._serialize(
-            {"s": "/GoToR", "f": enclose_in_parens(self.file), "d": self.dest}
+            {"s": "/GoToR", "f": PDFString(self.file, encrypt=True), "d": self.dest},
+            _security_handler=_security_handler,
+            _obj_id=_obj_id,
         )
 
 
@@ -75,8 +88,12 @@ class LaunchAction(Action):
         super().__init__(next_action)
         self.file = file
 
-    def serialize(self):
-        return super()._serialize({"s": "/Launch", "f": enclose_in_parens(self.file)})
+    def serialize(self, _security_handler=None, _obj_id=None):
+        return super()._serialize(
+            {"s": "/Launch", "f": PDFString(self.file, encrypt=True)},
+            _security_handler=_security_handler,
+            _obj_id=_obj_id,
+        )
 
 
 # Annotation & actions that we tested implementing,
