@@ -149,6 +149,7 @@ class CoerciveIntFlag(IntFlag):
 
 class WrapMode(CoerciveEnum):
     "Defines how to break and wrap lines in multi-line text."
+
     WORD = intern("WORD")
     "Wrap by word"
 
@@ -158,6 +159,7 @@ class WrapMode(CoerciveEnum):
 
 class CharVPos(CoerciveEnum):
     "Defines the vertical position of text relative to the line."
+
     SUP = intern("SUP")
     "Superscript"
 
@@ -243,6 +245,9 @@ class TextEmphasis(CoerciveIntFlag):
     U = 4
     "Underline"
 
+    S = 8
+    "Strikethrough"
+
     @property
     def style(self):
         return "".join(
@@ -268,6 +273,8 @@ class TextEmphasis(CoerciveIntFlag):
                 return cls.I
             if value.upper() == "UNDERLINE":
                 return cls.U
+            if value.upper() == "STRIKETHROUGH":
+                return cls.S
         return super(cls, cls).coerce(value)
 
 
@@ -280,7 +287,7 @@ class MethodReturnValue(CoerciveIntFlag):
     """
 
     PAGE_BREAK = 1
-    "The method will return a boolean indicating if a page break occured"
+    "The method will return a boolean indicating if a page break occurred"
 
     LINES = 2
     "The method will return a multi-lines array of strings, after performing word-wrapping"
@@ -488,6 +495,7 @@ class RenderStyle(CoerciveEnum):
 
 class TextMode(CoerciveIntEnum):
     "Values described in PDF spec section 'Text Rendering Mode'"
+
     FILL = 0
     STROKE = 1
     FILL_STROKE = 2
@@ -547,6 +555,7 @@ class YPos(CoerciveEnum):
 
 class Angle(CoerciveIntEnum):
     "Direction values used for mirror transformations specifying the angle of mirror line"
+
     NORTH = 90
     EAST = 0
     SOUTH = 270
@@ -1015,6 +1024,19 @@ class TextDirection(CoerciveEnum):
     "bottom to top"
 
 
+class OutputIntentSubType(CoerciveEnum):
+    "Definition for Output Intent Subtypes"
+
+    PDFX = Name("GTS_PDFX")
+    "PDF/X-1a which is based upon CMYK processing"
+
+    PDFA = Name("GTS_PDFA1")
+    "PDF/A (ISO 19005) standard to produce RGB output"
+
+    ISOPDF = Name("ISO_PDFE1")
+    "ISO_PDFE1 PDF/E standards (ISO 24517, all parts)"
+
+
 class PageLabelStyle(CoerciveEnum):
     "Style of the page label"
 
@@ -1068,3 +1090,14 @@ class PageOrientation(CoerciveEnum):
         if isinstance(value, str):
             value = value.upper()
         return super(cls, cls).coerce(value)
+
+
+class PDFResourceType(Enum):
+    EXT_G_STATE = intern("ExtGState")
+    COLOR_SPACE = intern("ColorSpace")
+    PATTERN = intern("Pattern")
+    SHADDING = intern("Shading")
+    X_OBJECT = intern("XObject")
+    FONT = intern("Font")
+    PROC_SET = intern("ProcSet")
+    PROPERTIES = intern("Properties")
