@@ -8,14 +8,16 @@ in non-backward-compatible ways.
 """
 
 import re, warnings
+import logging
 
 from bisect import bisect_left
 from collections import defaultdict
 from dataclasses import dataclass, replace
 from functools import lru_cache
-from typing import List, Optional, Tuple, Union
+from typing import Optional, Tuple, Union
 
 from fontTools import ttLib
+from fontTools.pens.ttGlyphPen import TTGlyphPen
 
 try:
     import uharfbuzz as hb
@@ -37,6 +39,8 @@ from .enums import FontDescriptorFlags, TextEmphasis, Align
 from .syntax import Name, PDFObject
 from .util import escape_parens
 
+LOGGER = logging.getLogger(__name__)
+
 
 @dataclass
 class FontFace:
@@ -73,6 +77,10 @@ class FontFace:
         )
 
     replace = replace
+    """
+    Create a new FontFace instance, with new values for some attributes.
+    Same as `dataclasses.replace()`
+    """
 
     @staticmethod
     def _override(current_value, override_value):
@@ -152,6 +160,7 @@ class TextStyle(FontFace):
             + f", t_margin={self.t_margin}, l_margin={self.l_margin}, b_margin={self.b_margin})"
         )
 
+    # override parent method
     def replace(
         self,
         /,
@@ -164,6 +173,10 @@ class TextStyle(FontFace):
         l_margin=None,
         b_margin=None,
     ):
+        """
+        Create a new TextStyle instance, with new values for some attributes.
+        Same as `dataclasses.replace()`
+        """
         return TextStyle(
             font_family=font_family or self.family,
             font_style=self.emphasis if emphasis is None else emphasis.style,
@@ -194,14 +207,27 @@ __pdoc__ = {"TitleStyle": False}  # Replaced by TextStyle
 
 class CoreFont:
     # RAM usage optimization:
-    __slots__ = ("i", "type", "name", "up", "ut", "cw", "fontkey", "emphasis")
+    __slots__ = (
+        "i",
+        "type",
+        "name",
+        "sp",
+        "ss",
+        "up",
+        "ut",
+        "cw",
+        "fontkey",
+        "emphasis",
+    )
 
     def __init__(self, fpdf, fontkey, style):
         self.i = len(fpdf.fonts) + 1
         self.type = "core"
         self.name = CORE_FONTS[fontkey]
-        self.up = -100
-        self.ut = 50
+        self.sp = 250  # strikethrough horizontal position
+        self.ss = 50  # strikethrough size (height)
+        self.up = -100  # underline horizontal position
+        self.ut = 50  # underline height
         self.cw = CORE_FONTS_CHARWIDTHS[fontkey]
         self.fontkey = fontkey
         self.emphasis = TextEmphasis.coerce(style)
@@ -226,6 +252,8 @@ class TTFFont:
         "desc",
         "glyph_ids",
         "hbfont",
+        "sp",
+        "ss",
         "up",
         "ut",
         "cw",
@@ -252,20 +280,57 @@ class TTFFont:
         )
 
         self.scale = 1000 / self.ttfont["head"].unitsPerEm
+
+        # check if the font is a TrueType and missing a .notdef glyph
+        # if it is missing, provide a fallback glyph
+        if "glyf" in self.ttfont and ".notdef" not in self.ttfont["glyf"]:
+            LOGGER.warning(
+                (
+                    "TrueType Font '%s' is missing the '.notdef' glyph. "
+                    "Fallback glyph will be provided."
+                ),
+                self.fontkey,
+            )
+            # draw a diagonal cross .notdef glyph
+            (xMin, xMax, yMin, yMax) = (
+                self.ttfont["head"].xMin,
+                self.ttfont["head"].xMax,
+                self.ttfont["head"].yMin,
+                self.ttfont["head"].yMax,
+            )
+            pen = TTGlyphPen(self.ttfont["glyf"])
+            pen.moveTo((xMin, yMin))
+            pen.lineTo((xMax, yMin))
+            pen.lineTo((xMax, yMax))
+            pen.lineTo((xMin, yMax))
+            pen.closePath()
+            pen.moveTo((xMin, yMin))
+            pen.lineTo((xMax, yMax))
+            pen.closePath()
+            pen.moveTo((xMax, yMin))
+            pen.lineTo((xMin, yMax))
+            pen.closePath()
+
+            self.ttfont["glyf"][".notdef"] = pen.glyph()
+            self.ttfont["hmtx"][".notdef"] = (xMax - xMin, yMax - yMin)
+
         default_width = round(self.scale * self.ttfont["hmtx"].metrics[".notdef"][0])
 
+        os2_table = self.ttfont["OS/2"]
+        post_table = self.ttfont["post"]
+
         try:
-            cap_height = self.ttfont["OS/2"].sCapHeight
+            cap_height = os2_table.sCapHeight
         except AttributeError:
             cap_height = self.ttfont["hhea"].ascent
 
         # entry for the PDF font descriptor specifying various characteristics of the font
         flags = FontDescriptorFlags.SYMBOLIC
-        if self.ttfont["post"].isFixedPitch:
+        if post_table.isFixedPitch:
             flags |= FontDescriptorFlags.FIXED_PITCH
-        if self.ttfont["post"].italicAngle != 0:
+        if post_table.italicAngle != 0:
             flags |= FontDescriptorFlags.ITALIC
-        if self.ttfont["OS/2"].usWeightClass >= 600:
+        if os2_table.usWeightClass >= 600:
             flags |= FontDescriptorFlags.FORCE_BOLD
 
         self.desc = PDFFontDescriptor(
@@ -277,8 +342,8 @@ class TTFFont:
                 f"[{self.ttfont['head'].xMin * self.scale:.0f} {self.ttfont['head'].yMin * self.scale:.0f}"
                 f" {self.ttfont['head'].xMax * self.scale:.0f} {self.ttfont['head'].yMax * self.scale:.0f}]"
             ),
-            italic_angle=int(self.ttfont["post"].italicAngle),
-            stem_v=round(50 + int(pow((self.ttfont["OS/2"].usWeightClass / 65), 2))),
+            italic_angle=int(post_table.italicAngle),
+            stem_v=round(50 + int(pow((os2_table.usWeightClass / 65), 2))),
             missing_width=default_width,
         )
 
@@ -289,6 +354,10 @@ class TTFFont:
         # saving only the keys we have a tuple with
         # the unicode characters available on the font
         self.cmap = self.ttfont.getBestCmap()
+        if not self.cmap:
+            raise NotImplementedError(
+                "Font not supported as it does not have a unicode cmap table - cf. issue #1396"
+            )
 
         # saving a list of glyph ids to char to allow
         # subset by unicode (regular) and by glyph
@@ -312,18 +381,13 @@ class TTFFont:
 
         self.missing_glyphs = []
 
-        # include numbers in the subset! (if alias present)
-        # ensure that alias is mapped 1-by-1 additionally (must be replaceable)
-        sbarr = "\x00 \r\n"
-        if fpdf.str_alias_nb_pages:
-            sbarr += "0123456789"
-            sbarr += fpdf.str_alias_nb_pages
-
         self.name = re.sub("[ ()]", "", self.ttfont["name"].getBestFullName())
-        self.up = round(self.ttfont["post"].underlinePosition * self.scale)
-        self.ut = round(self.ttfont["post"].underlineThickness * self.scale)
+        self.up = round(post_table.underlinePosition * self.scale)
+        self.ut = round(post_table.underlineThickness * self.scale)
+        self.sp = round(os2_table.yStrikeoutPosition * self.scale)
+        self.ss = round(os2_table.yStrikeoutSize * self.scale)
         self.emphasis = TextEmphasis.coerce(style)
-        self.subset = SubsetMap(self, [ord(char) for char in sbarr])
+        self.subset = SubsetMap(self)
 
     def __repr__(self):
         return f"TTFFont(i={self.i}, fontkey={self.fontkey})"
@@ -332,19 +396,19 @@ class TTFFont:
         self.ttfont.close()
         self.hbfont = None
 
-    def get_text_width(self, text, font_size_pt, text_shaping_parms):
-        if text_shaping_parms:
-            return self.shaped_text_width(text, font_size_pt, text_shaping_parms)
+    def get_text_width(self, text, font_size_pt, text_shaping_params):
+        if text_shaping_params:
+            return self.shaped_text_width(text, font_size_pt, text_shaping_params)
         return (len(text), sum(self.cw[ord(c)] for c in text) * font_size_pt * 0.001)
 
-    def shaped_text_width(self, text, font_size_pt, text_shaping_parms):
+    def shaped_text_width(self, text, font_size_pt, text_shaping_params):
         """
         When texts are shaped, the length of a string is not always the sum of all individual character widths
         This method will invoke harfbuzz to perform the text shaping and return the sum of "x_advance"
         and "x_offset" for each glyph. This method works for "left to right" or "right to left" texts.
         """
         _, glyph_positions = self.perform_harfbuzz_shaping(
-            text, font_size_pt, text_shaping_parms
+            text, font_size_pt, text_shaping_params
         )
 
         # If there is nothing to render (harfbuzz returns None), we return 0 text width
@@ -360,7 +424,7 @@ class TTFFont:
 
     # Disabling this check - looks like cython confuses pylint:
     # pylint: disable=no-member
-    def perform_harfbuzz_shaping(self, text, font_size_pt, text_shaping_parms):
+    def perform_harfbuzz_shaping(self, text, font_size_pt, text_shaping_params):
         """
         This method invokes Harfbuzz to perform text shaping of the input string
         """
@@ -371,13 +435,13 @@ class TTFFont:
         buf.cluster_level = 1
         buf.add_str("".join(text))
         buf.guess_segment_properties()
-        features = text_shaping_parms["features"]
-        if text_shaping_parms["fragment_direction"]:
-            buf.direction = text_shaping_parms["fragment_direction"].value
-        if text_shaping_parms["script"]:
-            buf.script = text_shaping_parms["script"]
-        if text_shaping_parms["language"]:
-            buf.language = text_shaping_parms["language"]
+        features = text_shaping_params["features"]
+        if text_shaping_params["fragment_direction"]:
+            buf.direction = text_shaping_params["fragment_direction"].value
+        if text_shaping_params["script"]:
+            buf.script = text_shaping_params["script"]
+        if text_shaping_params["language"]:
+            buf.language = text_shaping_params["language"]
         hb.shape(self.hbfont, buf, features)
         return buf.glyph_infos, buf.glyph_positions
 
@@ -390,7 +454,7 @@ class TTFFont:
             txt_mapped += chr(self.subset.pick(uni))
         return f'({escape_parens(txt_mapped.encode("utf-16-be").decode("latin-1"))}) Tj'
 
-    def shape_text(self, text, font_size_pt, text_shaping_parms):
+    def shape_text(self, text, font_size_pt, text_shaping_params):
         """
         This method will invoke harfbuzz for text shaping, include the mapping code
         of the glyphs on the subset and map input characters to the cluster codes
@@ -398,7 +462,7 @@ class TTFFont:
         if len(text) == 0:
             return []
         glyph_infos, glyph_positions = self.perform_harfbuzz_shaping(
-            text, font_size_pt, text_shaping_parms
+            text, font_size_pt, text_shaping_params
         )
         text_info = []
 
@@ -509,21 +573,20 @@ class SubsetMap:
     Holds a mapping of used characters and their position in the font's subset
 
     Characters that must be mapped on their actual unicode must be part of the
-    `identities` list during object instanciation. These non-negative values should
+    `identities` list during object instantiation. These non-negative values should
     only appear once in the list. `pick()` can be used to get the characters
     corresponding position in the subset. If it's not yet part of the object, a new
     position is acquired automatically. This implementation always tries to return
     the lowest possible representation.
     """
 
-    def __init__(self, font: TTFFont, identities: List[int]):
+    def __init__(self, font: TTFFont):
         super().__init__()
         self.font = font
         self._next = 0
 
-        # sort list to ease deletion once _next
-        # becomes higher than first reservation
-        self._reserved = sorted(identities)
+        # 0x00 ".notdef" and 0x20 "space" are reserved
+        self._reserved = [0x00, 0x20]
 
         # Maps Glyph instances to character IDs (integers):
         self._char_id_per_glyph = {}
