@@ -36,12 +36,14 @@ class GraphicsStateMixin:
                 fill_color=self.DEFAULT_FILL_COLOR,
                 text_color=self.DEFAULT_TEXT_COLOR,
                 underline=False,
+                strikethrough=False,
                 font_style="",
                 font_stretching=100,
                 char_spacing=0,
                 font_family="",
                 font_size_pt=0,
                 current_font={},
+                current_font_is_set_on_page=False,
                 dash_pattern=dict(dash=0, gap=0, phase=0),
                 line_width=0,
                 text_mode=TextMode.FILL,
@@ -60,15 +62,18 @@ class GraphicsStateMixin:
         super().__init__(*args, **kwargs)
 
     def _push_local_stack(self, new=None):
-        if new:
-            self.__statestack.append(new)
-        else:
-            self.__statestack.append(self._get_current_graphics_state())
+        "Push a graphics state on the stack"
+        if not new:
+            new = self._get_current_graphics_state()
+        self.__statestack.append(new)
+        return new
 
     def _pop_local_stack(self):
+        "Pop the last graphics state on the stack"
         return self.__statestack.pop()
 
     def _get_current_graphics_state(self):
+        "Retrieve the current graphics state"
         # "current_font" must be shallow copied
         # "text_shaping" must be deep copied (different fragments may have different languages/direction)
         # Doing a whole copy and then creating a copy of text_shaping to achieve this result
@@ -77,6 +82,7 @@ class GraphicsStateMixin:
         return gs
 
     def _is_current_graphics_state_nested(self):
+        "Indicate if the stack contains items (else it is empty)"
         return len(self.__statestack) > 1
 
     @property
@@ -111,6 +117,14 @@ class GraphicsStateMixin:
     def underline(self, v):
         self.__statestack[-1]["underline"] = v
 
+    @property
+    def strikethrough(self):
+        return self.__statestack[-1]["strikethrough"]
+
+    @strikethrough.setter
+    def strikethrough(self, v):
+        self.__statestack[-1]["strikethrough"] = v
+
     @property
     def font_style(self):
         return self.__statestack[-1]["font_style"]
@@ -167,6 +181,14 @@ class GraphicsStateMixin:
     def current_font(self, v):
         self.__statestack[-1]["current_font"] = v
 
+    @property
+    def current_font_is_set_on_page(self):
+        return self.__statestack[-1]["current_font_is_set_on_page"]
+
+    @current_font_is_set_on_page.setter
+    def current_font_is_set_on_page(self, v):
+        self.__statestack[-1]["current_font_is_set_on_page"] = v
+
     @property
     def dash_pattern(self):
         return self.__statestack[-1]["dash_pattern"]
@@ -359,3 +381,11 @@ class GraphicsStateMixin:
                 self.fill_color if self.fill_color != self.DEFAULT_FILL_COLOR else None
             ),
         )
+
+
+__pdoc__ = {
+    "GraphicsStateMixin._push_local_stack": True,
+    "GraphicsStateMixin._pop_local_stack": True,
+    "GraphicsStateMixin._get_current_graphics_state": True,
+    "GraphicsStateMixin._is_current_graphics_state_nested": True,
+}
