@@ -137,12 +137,9 @@ class Name(str):
 
 
 class PDFObject:
-    """
-    Main features of this class:
-    * delay ID assignement
-    * implement serializing
-    """
-
+    # Main features of this class:
+    # * delay ID assignment
+    # * implement serializing
     # Note: several child classes use __slots__ to save up some memory
 
     def __init__(self):
@@ -331,7 +328,7 @@ class PDFArray(list):
     def serialize(self, _security_handler=None, _obj_id=None):
         if all(isinstance(elem, str) for elem in self):
             serialized_elems = " ".join(self)
-        elif all(isinstance(elem, int) for elem in self):
+        elif all(isinstance(elem, (int, float)) for elem in self):
             serialized_elems = " ".join(str(elem) for elem in self)
         else:
             serialized_elems = "\n".join(
@@ -380,3 +377,14 @@ class DestinationXYZ(Destination):
         top = round(self.top, 2) if isinstance(self.top, float) else self.top
         assert self.page_ref
         return f"[{self.page_ref} /XYZ {left} {top} {self.zoom}]"
+
+    def replace(self, page=None, top=None, left=None, zoom=None):
+        assert (
+            not self.page_ref
+        ), "DestinationXYZ should not be copied after serialization"
+        return DestinationXYZ(
+            page=self.page_number if page is None else page,
+            top=self.top if top is None else top,
+            left=self.left if left is None else left,
+            zoom=self.zoom if zoom is None else zoom,
+        )
