@@ -37,7 +37,8 @@ def test_set_unknown_style():
     with pytest.raises(ValueError) as e:
         pdf.set_font("Times", style="bold")
     assert (
-        str(e.value) == "Unknown style provided (only B/I/U letters are allowed): BDLO"
+        str(e.value)
+        == "Unknown style provided (only B/I/S/U letters are allowed): BDLO"
     )
 
 
@@ -87,7 +88,7 @@ def test_set_font_aliases_as_font():
 
         # Test if font family is set correctly
         assert pdf.font_family == alternative
-    # Test if the fonts were added in this order and without duplicats:
+    # Test if the fonts were added in this order and without duplicates:
     # helvetica, courier, times
     assert [*pdf.fonts] == ["helvetica", "courier", "times"]
 
