@@ -194,6 +194,16 @@ def test_html_bold_italic_underline(tmp_path):
     assert_pdf_equal(pdf, HERE / "html_bold_italic_underline.pdf", tmp_path)
 
 
+def test_html_strikethrough(tmp_path):
+    pdf = FPDF()
+    pdf.add_font(fname=HERE / "../fonts/DejaVuSans.ttf")
+    pdf.set_font_size(30)
+    pdf.add_page()
+    pdf.write_html("<s>strikethrough</s>")
+    pdf.write_html('<font face="DejaVuSans"><s>strikethrough</s></font>')
+    assert_pdf_equal(pdf, HERE / "html_strikethrough.pdf", tmp_path)
+
+
 def test_html_customize_ul(tmp_path):
     html = """<ul>
         <li><b>term1</b>: definition1</li>
@@ -660,7 +670,7 @@ def test_html_ln_outside_p(tmp_path):
     pdf.add_page()
     pdf.set_font("times", size=18)
     pdf.write_html(
-        "<p>someting in paragraph</p><li>causing _ln() outside paragraph</li>"
+        "<p>something in paragraph</p><li>causing _ln() outside paragraph</li>"
     )
     assert_pdf_equal(pdf, HERE / "html_ln_outside_p.pdf", tmp_path)
 
@@ -721,6 +731,20 @@ def test_html_and_section_title_styles_with_deprecated_TitleStyle():
         )
 
 
+def test_html_link_underline(tmp_path):
+    pdf = FPDF()
+    pdf.add_page()
+    pdf.write_html(
+        '<a href="https://py-pdf.github.io/fpdf2/">inside link</a> - outside link'
+    )
+    pdf.write_html(
+        '<a href="https://www.flickr.com/photos/ryzom/14726336322/in/album-72157645935788203/">Tryker</a>'
+        " - Ryzom"
+        ' - <a href="https://creativecommons.org/licenses/by-sa/2.0/">CC BY-SA 2.0</a>'
+    )
+    assert_pdf_equal(pdf, HERE / "html_link_underline.pdf", tmp_path)
+
+
 def test_html_link_style(tmp_path):
     pdf = FPDF()
     pdf.add_page()
