@@ -6,7 +6,7 @@ class PDF(FPDF):
         # Rendering logo:
         self.image("../docs/fpdf2-logo.png", 10, 8, 33)
         # Setting font: helvetica bold 15
-        self.set_font("helvetica", "B", 15)
+        self.set_font("helvetica", style="B", size=15)
         # Moving cursor to the right:
         self.cell(80)
         # Printing title:
@@ -18,7 +18,7 @@ class PDF(FPDF):
         # Position cursor at 1.5 cm from bottom:
         self.set_y(-15)
         # Setting font: helvetica italic 8
-        self.set_font("helvetica", "I", 8)
+        self.set_font("helvetica", style="I", size=8)
         # Printing page number:
         self.cell(0, 10, f"Page {self.page_no()}/{{nb}}", align="C")
 
